@@ -8,11 +8,12 @@ equivalent to non conflict files laying beside them), some of them really
 differs from their neighborhoods. The aim of this script is to resolve
 conflict files of both types. """
 
-__version__ = "0.0.7"
+__version__ = "0.0.8"
 
 # pylint: disable=C0103, C0111, W0105, W0141, W0142
 
 import argparse
+import datetime
 import errno
 import filecmp
 import logging as logger
@@ -43,9 +44,11 @@ class Keep(IntEnum):
     normal = 2
     both = 3
 
+dummy_program = defaultdict(lambda: defaultdict(str))
 
 programs = {
-    None: defaultdict(lambda: defaultdict(str)),
+    None: dummy_program,
+    'time': dummy_program,
     'merge': {
         'kdiff3': {
             'arguments': '-m $conflict $normal -o $normal',
@@ -78,6 +81,11 @@ programs = {
 }
 
 
+def modification_datetime(filename):
+    t = os.path.getmtime(str(filename))
+    return datetime.datetime.fromtimestamp(t)
+
+
 class FileManipulatorMeta(type):
     def __str__(cls):
         return cls.__name__.replace(cls.__base__.__name__, '').lower()
@@ -389,6 +397,20 @@ class MergeConflictResolver(ConflictResolver):
         return result
 
 
+class TimeConflictResolver(ConflictResolver):
+    resolving_type = 'time'
+
+    def resolve(self, conflict_file_path):
+        result = super().resolve(conflict_file_path)
+        if not result:
+            mod_time = {
+                modification_datetime(f): f for f in
+                [conflict_file_path, self.normal_file(conflict_file_path)]
+            }
+            self.deleter.delete(mod_time[sorted(mod_time)[0]])
+        return True
+
+
 class ListConflictResolver(ConflictResolver):
     resolving_type = None
 
@@ -463,6 +485,9 @@ def parse_arguments():
     class MergeConflictResolverAction(ConflictResolverAction):
         pass
 
+    class TimeConflictResolverAction(ConflictResolverAction):
+        pass
+
     class ListConflictResolverAction(ConflictResolverAction):
         pass
 
@@ -496,6 +521,10 @@ def parse_arguments():
     conflict_resolver_group.add_argument('-m', '--merge',
                                          action=MergeConflictResolverAction,
                                          help="merge conflict files")
+    conflict_resolver_group.add_argument('-T', '--time',
+                                         action=TimeConflictResolverAction,
+                                         help="resolve conflict files by "
+                                              "modification time")
     conflict_resolver_group.add_argument('-l', '--list',
                                          action=ListConflictResolverAction,
                                          help="list conflict files")
